Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(992)

Unified Diff: third_party/WebKit/Source/platform/weborigin/KURL.h

Issue 2647633006: Make KURL::protocolIs take StringView (+ DCHECK cleanups) (Closed)
Patch Set: comment only changes Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/weborigin/KURL.h
diff --git a/third_party/WebKit/Source/platform/weborigin/KURL.h b/third_party/WebKit/Source/platform/weborigin/KURL.h
index c6d38fb6584ff517ec8c7239d05fd0ff92812493..489bc70117b777df02ae4930230c227455c4e8a3 100644
--- a/third_party/WebKit/Source/platform/weborigin/KURL.h
+++ b/third_party/WebKit/Source/platform/weborigin/KURL.h
@@ -136,9 +136,9 @@ class PLATFORM_EXPORT KURL {
String baseAsString() const;
- // Returns true if the current URL's protocol is the same as the null-
- // terminated ASCII argument. The argument must be lower-case.
- bool protocolIs(const char*) const;
+ // Returns true if the current URL's protocol is the same as the StringView
+ // argument. The argument must be lower-case.
+ bool protocolIs(const StringView protocol) const;
bool protocolIsData() const { return protocolIs("data"); }
// This includes at least about:blank and about:srcdoc.
bool protocolIsAbout() const { return protocolIs("about"); }

Powered by Google App Engine
This is Rietveld 408576698